Re:Much faster incremental apt updates
by julian-klode on Thursday January 07, 2016 @08:42PM
(#10862325)
So, we have basically rewritten the tornado patch idea using the C++17 string_view API (subset implemented in APT::StringView). This improved performance by about 10% on my test systems.
Here's the commit:
http://anonscm.debian.org/cgit/apt/apt.git/commit/?id=eff0c2...
also further improvement:
http://anonscm.debian.org/cgit/apt/apt.git/commit/?id=dd5927...
and finally, dropping strings out of StoreString(), so it's now almost entirely gone:
http://anonscm.debian.org/cgit/apt/apt.git/commit/?id=869700...